@@ -3,11 +3,8 @@
 #' @noRd
 .onLoad <- function(libname, pkgname) {
   op <- options()
-  op.patentsview <- list(
-    pv_browser = "false"
-  )
+  op.patentsview <- list(pv_browser = "false")
   toset <- !(names(op.patentsview) %in% names(op))
   if (any(toset)) options(op.patentsview[toset])
-
   invisible()
-}
\ No newline at end of file
+}
